pygeodesy.auxilats.auxLat.AuxLat

Package pygeodesy :: Package auxilats :: Module auxLat :: Class AuxLat |
[frames] | no frames]

# Class AuxLat

       object --+
                |
     named._Named --+
                    |
    auxAngle.AuxAngle --+
                        |
                       AuxLat

Known Subclasses:
  - auxDLat.AuxDLat

Base class for accurate conversion between Auxiliary latitudes on an ellipsoid.

Latitudes are represented by AuxAngle instances in order to maintain precision near the poles, Authalic latitude `Xi`, Conformal `Chi`, Geocentric `Theta`, Geographic `Phi`, Parametric `Beta` and Rectifying `Mu`.

See Also: Karney's C++ class AuxLatitude.

Instance Methods
__init__(self, a_earth=Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=298.257223`...`, f=None, b=None, **ALorder_name) New AuxLat instance on an ellipsoid or datum. |
Authalic(self, Phi, **diff_name) Convert Geographic to Aunthalic latitude. |
AuthalicRadius2(self, exact=False, f_max=0.1) Get the Authalic radius squared. |
Conformal(self, Phi, **diff_name) Convert Geographic to Conformal latitude. |
convert(self, auxout, Zeta_d, exact=False) |
Geocentric(self, Phi, **diff_name) Convert Geographic to Geocentric latitude. |
Geodetic(self, Phi, **name) Convert Geographic to Geodetic latitude. |
Parametric(self, Phi, **diff_name) Convert Geographic to Parametric latitude. |
Reduced(self, Phi, **diff_name) Convert Geographic to Parametric latitude. |
Rectifying(self, Phi, **diff_name) Convert Geographic to Rectifying latitude. |
RectifyingRadius(self, exact=False) Get the Rectifying radius. |
Inherited from `auxAngle.AuxAngle`: `__abs__`, `__add__`, `__bool__`, `__eq__`, `__float__`, `__iadd__`, `__isub__`, `__ne__`, `__neg__`, `__pos__`, `__radd__`, `__rsub__`, `__str__`, `__sub__`, `copyquadrant`, `normal`, `toBeta`, `toChi`, `toMu`, `toPhi` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `auxAngle.AuxAngle`: `fromDegrees`, `fromLambertianDegrees`, `fromLambertianRadians`, `fromRadians`

Properties
| a Get the `ellipsoid`'s equatorial radius (`meter`, conventionally).
| equatoradius Get the `ellipsoid`'s equatorial radius (`meter`, conventionally).
| ALorder Get the AuxLat order (`int`, 4, 6 or 8).
| b Get the `ellipsoid`'s polar radius (`meter`, conventionally).
| polaradius Get the `ellipsoid`'s polar radius (`meter`, conventionally).
| ellipsoid Get the ellipsoid (Ellipsoid).
| f Get the `ellipsoid`'s flattening (`scalar`).
| flattening Get the `ellipsoid`'s flattening (`scalar`).
Inherited from `auxAngle.AuxAngle`: `diff`, `iteration`, `normalized`, `tan`, `toDegrees`, `toLambertianDegrees`, `toLambertianRadians`, `toRadians`, `x`, `y` Inherited from `named._Named`: `classname`, `classnaming`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_earth=Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=298.257223`...`, f=None, b=None, **ALorder_name) (Constructor) |
New AuxLat instance on an ellipsoid or datum. Arguments: `a_earth` - Equatorial radius, semi-axis (`meter`) or an ellipsoid or datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `f` - Flattening: (a - b) / a (`float`, near zero for spherical), required if `a_earth` is `scalar` and `b=None`. `b` - Optional polar radius, semi-axis (`meter`, required if `a_earth` is `scalar` and `f=None`. `ALorder_name` - Optional `name=NN` (`str`) and optional order of this AuxLat `ALorder=6`, see property `ALorder`. Raises: `AuxError` - Invalid `y_angle`, `x` or `aux`. Overrides: object.__init__

### Authalic (self, Phi, **diff_name) |
Convert Geographic to Aunthalic latitude. Arguments: `Phi` - Geographic latitude (AuxAngle). `diff_name` - Use `diff=True` to set `diff` optional `name=NN`. Returns: Parametric latitude, `Beta` (AuxAngle).

### AuthalicRadius2 (self, exact=False, f_max=0.1) |
Get the Authalic radius squared. Arguments: `exact` - If `True`, use the exact expression, otherwise the Taylor series. `f_max` - `Flattening` not to exceed (`float`). Returns: Authalic radius squared (`meter` squared, same units as the ellipsoid axes). Raises: `AuxError` - If `exact=False` and `abs(flattening)` exceeds `f_max`.

### Conformal (self, Phi, **diff_name) |
Convert Geographic to Conformal latitude. Arguments: `Phi` - Geographic latitude (AuxAngle). `diff_name` - Use `diff=True` to set `diff` and an optional `name=NN`. Returns: Conformal latitude, `Chi` (AuxAngle).

### Geocentric (self, Phi, **diff_name) |
Convert Geographic to Geocentric latitude. Arguments: `Phi` - Geographic latitude (AuxAngle). `diff_name` - Use `diff=True` to set `diff` and an optional `name=NN`. Returns: Geocentric latitude, `Phi` (AuxAngle).

### Geodetic (self, Phi, **name) |
Convert Geographic to Geodetic latitude. Arguments: `Phi` - Geographic latitude (AuxAngle). `name` - Optional `name=NN` (`str`). Returns: Geodetic latitude, `Phi` (AuxAngle).

### Parametric (self, Phi, **diff_name) |
Convert Geographic to Parametric latitude. Arguments: `Phi` - Geographic latitude (AuxAngle). `diff_name` - Use `diff=True` to set `diff` and an optional `name=NN`. Returns: Parametric latitude, `Beta` (AuxAngle).

### Reduced (self, Phi, **diff_name) |
Convert Geographic to Parametric latitude. Arguments: `Phi` - Geographic latitude (AuxAngle). `diff_name` - Use `diff=True` to set `diff` and an optional `name=NN`. Returns: Parametric latitude, `Beta` (AuxAngle).

### Rectifying (self, Phi, **diff_name) |
Convert Geographic to Rectifying latitude. Arguments: `Phi` - Geographic latitude (AuxAngle). `diff_name` - Use `diff=True` to set `diff` and an optional `name=NN`. Returns: Rectifying latitude, `Mu` (AuxAngle).

### RectifyingRadius (self, exact=False) |
Get the Rectifying radius. Arguments: `exact` - If `True`, use the exact expression, otherwise the Taylor series. Returns: Rectifying radius (Meter, same units as the ellipsoid axes).

Property Details

### a Get the `ellipsoid`'s equatorial radius (`meter`, conventionally). Get method: a(self) - Get the `ellipsoid`'s equatorial radius (`meter`, conventionally). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatoradius Get the `ellipsoid`'s equatorial radius (`meter`, conventionally). Get method: a(self) - Get the `ellipsoid`'s equatorial radius (`meter`, conventionally). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ALorder Get the AuxLat order (`int`, 4, 6 or 8). Get method: ALorder(self) - Get the AuxLat order (`int`, 4, 6 or 8). Set method: ALorder(self, order) - Set the AuxLat order (`int`, 4, 6 or 8). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### b Get the `ellipsoid`'s polar radius (`meter`, conventionally). Get method: b(self) - Get the `ellipsoid`'s polar radius (`meter`, conventionally). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### polaradius Get the `ellipsoid`'s polar radius (`meter`, conventionally). Get method: b(self) - Get the `ellipsoid`'s polar radius (`meter`, conventionally). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ellipsoid Get the ellipsoid (Ellipsoid). Get method: ellipsoid(self) - Get the ellipsoid (Ellipsoid). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f Get the `ellipsoid`'s flattening (`scalar`). Get method: f(self) - Get the `ellipsoid`'s flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening Get the `ellipsoid`'s flattening (`scalar`). Get method: f(self) - Get the `ellipsoid`'s flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.